pub struct ChannelPolicy {
pub min_expiry_in_seconds: u64,
pub min_capacity: u64,
pub max_amount_per_output: Option<u64>,
}Expand description
Funding-time validation thresholds for a given unit, returned by
SpilmanHost::get_channel_policy.
Fields
min_expiry_in_seconds: u64Minimum seconds between now and the channel expiry timestamp.
min_capacity: u64Minimum channel capacity (in the unit’s base denomination).
max_amount_per_output: Option<u64>Optional cap on the largest single proof denomination.