pub struct EstablishedChannel {
pub params: ChannelParameters,
pub funding_proofs: Vec<Proof>,
}Expand description
An established Spilman payment channel Contains all channel components after funding transaction is complete
Fields
params: ChannelParametersChannel parameters (includes shared_secret)
funding_proofs: Vec<Proof>Locked proofs (2-of-2 multisig with expiry-based refund)
Implementations
Sourceimpl EstablishedChannel
impl EstablishedChannel
Sourcepub fn new(
params: ChannelParameters,
funding_proofs: Vec<Proof>,
) -> Result<Self, Error>
pub fn new( params: ChannelParameters, funding_proofs: Vec<Proof>, ) -> Result<Self, Error>
Create new established channel
Sourcepub async fn check_funding_token_state<M>(
&self,
mint_connection: &M,
) -> Result<ProofState, Error>where
M: MintConnection + ?Sized,
pub async fn check_funding_token_state<M>(
&self,
mint_connection: &M,
) -> Result<ProofState, Error>where
M: MintConnection + ?Sized,
Check the state of the funding token using NUT-07
Since all funding proofs are spent together (they’re all inputs to the commitment transaction), checking any one of them is sufficient to determine if the funding token has been spent. This method checks the first funding proof and returns its state.
Returns the state (UNSPENT, PENDING, or SPENT) of the funding token.